CustomRefKt

Struct CustomRefKt 

pub struct CustomRefKt<'a, const RATE: usize> { /* private fields */ }
Customized KangarooTwelve hasher generic over rate with borrrowed customization string.

Implementations

Source

impl<'a, const RATE: usize> CustomRefKt<'a, RATE>

pub fn new_customized(customization: &'a [u8]) -> Self

Create new customized KangarooTwelve hasher with borrrowed customization string.

Note that this is an inherent method and CustomRefKt does not implement the CustomizedInit trait.