pub struct CustomRefKt<'a, const RATE: usize> { /* private fields */ }Expand description
Customized KangarooTwelve hasher generic over rate with borrrowed customization string.
Implementations
Sourceimpl<'a, const RATE: usize> CustomRefKt<'a, RATE>
impl<'a, const RATE: usize> CustomRefKt<'a, RATE>
Sourcepub fn new_customized(customization: &'a [u8]) -> Self
pub fn new_customized(customization: &'a [u8]) -> Self
Create new customized KangarooTwelve hasher with borrrowed customization string.
Note that this is an inherent method and CustomRefKt does not implement
the CustomizedInit trait.